lilypondparsertools.parse_reduced_ly_syntax
===========================================

.. autofunction:: abjad.tools.lilypondparsertools.parse_reduced_ly_syntax.parse_reduced_ly_syntax
   :noindex:
